@@ -42,7 +42,8 @@ class CNV(object):
         profile['timeS'] # Return the time in Seconds
         profile.attributes # Return a dictionary with the file header
     """
-    def __init__(self, raw_text, defaults=None):
+    def __init__(self, raw_text, defaults=None, verbose=False):
+        self.verbose = verbose
         self.raw_text = raw_text
         self.defaults = defaults
         self.attributes = {}
@@ -103,7 +104,8 @@ class CNV(object):
             r = rule['header'] + rule['sep'] + rule['data']
             content_re = re.compile(r, re.VERBOSE)
             if re.search(r, self.raw_text, re.VERBOSE):
-                print "Using rules from: ", rule_file
+                if self.verbose is True:
+                    print "Using rules from: ", rule_file
                 self.rule = rule
                 self.parsed = content_re.search(self.raw_text).groupdict()
                 return
@@ -288,43 +290,46 @@ class CNV(object):
             !! ATENTION!!! Might be a good idea to store lat,lon as floats
               with min. and sec. as fractions.
         """
-        if 'latitude' in self.attributes:
-                lat = re.search(self.rule['latitude'],
-                        self.attributes['latitude'],
-                        re.VERBOSE).groupdict()
-        elif 'notes' in self.raw_header().keys():
-                lat = re.search(self.rule['latitude'],
-                        self.raw_header()['notes'],
-                        re.VERBOSE).groupdict()
         try:
-                lat_deg = int(lat['degree'])
-                lat_min = float(lat['minute'])
-                #self.attributes['lat_deg'] = lat_deg
-                #self.attributes['lat_min'] = lat_min
-                self.attributes['latitude'] = lat_deg + lat_min/60.
-                if lat['hemisphere'] in ['S', 's']:
-                    self.attributes['latitude'] = -1*self.attributes['latitude']
+            if 'latitude' in self.attributes:
+                    lat = re.search(self.rule['latitude'],
+                            self.attributes['latitude'],
+                            re.VERBOSE).groupdict()
+            elif 'notes' in self.raw_header().keys():
+                    lat = re.search(self.rule['latitude'],
+                            self.raw_header()['notes'],
+                            re.VERBOSE).groupdict()
+
+            lat_deg = int(lat['degree'])
+            lat_min = float(lat['minute'])
+            #self.attributes['lat_deg'] = lat_deg
+            #self.attributes['lat_min'] = lat_min
+            self.attributes['latitude'] = lat_deg + lat_min/60.
+            if lat['hemisphere'] in ['S', 's']:
+                self.attributes['latitude'] = -1*self.attributes['latitude']
         except:
+                #self.attributes['latitude'] = None
                 pass
 
-        if 'longitude' in self.attributes:
-                lon = re.search(self.rule['longitude'],
-                        self.attributes['longitude'],
-                        re.VERBOSE).groupdict()
-        elif 'notes' in self.raw_header().keys():
-                lon = re.search(self.rule['longitude'],
-                        self.raw_header()['notes'],
-                        re.VERBOSE).groupdict()
-
         try:
-                lon_deg = int(lon['degree'])
-                lon_min = float(lon['minute'])
-                #self.attributes['lon_deg'] = lon_deg
-                #self.attributes['lon_min'] = lon_min
-                self.attributes['longitude'] = lon_deg + lon_min/60.
-                if lon['hemisphere'] in ['W', 'w']:
-                    self.attributes['longitude'] = -1*self.attributes['longitude']
+            if 'longitude' in self.attributes:
+                    lon = re.search(self.rule['longitude'],
+                            self.attributes['longitude'],
+                            re.VERBOSE).groupdict()
+            elif 'notes' in self.raw_header().keys():
+                    lon = re.search(self.rule['longitude'],
+                            self.raw_header()['notes'],
+                            re.VERBOSE).groupdict()
+
+            lon_deg = int(lon['degree'])
+            lon_min = float(lon['minute'])
+            #self.attributes['lon_deg'] = lon_deg
+            #self.attributes['lon_min'] = lon_min
+            self.attributes['longitude'] = lon_deg + lon_min/60.
+            if lon['hemisphere'] in ['W', 'w']:
+                self.attributes['longitude'] = -1*self.attributes['longitude']
         except:
+                #self.attributes['longitude'] = None
                 pass
 
     def as_DataFrame(self):
@@ -344,8 +349,10 @@ class CNV(object):
             tmp[self[k].mask] = np.nan
             output[k] = tmp
         output = pd.DataFrame(output)
-        output['latitude'] = self.attributes['latitude']
-        output['longitude'] = self.attributes['longitude']
+        toload = ['latitude', 'longitude', 'datetime']
+        for a in toload:
+            if a in self.attributes:
+                output[a] = self.attributes[a]
 
         return output
 
@@ -358,9 +365,8 @@ class CNV(object):
             Might be a good idea to move these tests outside the
               class.
         """
-
         nquan = int(self.attributes['nquan'])
-        if nquan >= len(self.keys()):
+        if nquan != len(self.keys()):
             print "It was supposed to has %s variables." % (nquan)
 
         nvalues = int(self.attributes['nvalues'])
